@@ -447,17 +447,7 @@ class WordType(caching.base.CachingMixin,models.Model):
         if self.ND is not None and self.FWND is not None:
             return self.ND,self.FWND
         any_segment = '[A-Za-z]{1,2}'
-        qs = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
-                                FROM buckeyebrowser_underlying
-                                INNER JOIN buckeyebrowser_segmenttype
-                                ON buckeyebrowser_segmenttype.id
-                                    = buckeyebrowser_underlying.SegmentType_id
-                                WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""})
-        word = qs.get(pk = self.pk)
-        phones = word.ur.split(" ")
+        phones = map(str,self.UR.all())
         patterns = []
         for i in range(len(phones)):
             patt = phones[:i] #Substitutions
@@ -471,7 +461,17 @@ class WordType(caching.base.CachingMixin,models.Model):
             patt.append(any_segment)
             patt.extend(phones[i:])
             patterns.append('^'+' '.join(patt) +'$')
-        neighs = qs.filter(ur__regex = '|'.join(patterns))
+        neighs = WordType.objects.filter(Label__regex="^[^{<]").extra(
+                    select = {
+                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                                FROM buckeyebrowser_underlying
+                                INNER JOIN buckeyebrowser_segmenttype
+                                ON buckeyebrowser_segmenttype.id
+                                    = buckeyebrowser_underlying.SegmentType_id
+                                WHERE buckeyebrowser_underlying.WordType_id
+                                    =buckeyebrowser_wordtype.id)"""},
+                    where = ["ur REGEXP '%s'"],
+                    params = ['|'.join(patterns)])
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
         self.ND = neighCount
@@ -499,7 +499,16 @@ class WordType(caching.base.CachingMixin,models.Model):
 
     def setViteLuceProb(self):
         any_segment = '[A-Za-z]{1,2}'
-        qs = WordType.objects.filter(Label__regex="^[^{<]").extra(
+        patterns = []
+        SPprob = 0.0
+        BPprob = 0.0
+        phones = map(str,self.UR.all())
+        for i in range(len(phones)):
+            patt = [any_segment] * i
+            patt.append(phones[i])
+            pattern = '^'+' '.join(patt) +'.*$'
+            totPattern = '^'+' '.join([any_segment] * (i+1)) +'.*$'
+            count = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     select = {
                         'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
@@ -507,35 +516,48 @@ class WordType(caching.base.CachingMixin,models.Model):
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""})
-        word = qs.get(pk = self.pk)
-        patterns = []
-        SPprob = 0.0
-        BPprob = 0.0
-        phones = word.ur.split(" ")
-        for i in range(len(phones)):
-            patt = [any_segment] * i
-            patt.append(phones[i])
-            pattern = '^'+' '.join(patt) +'.*$'
-            totPattern = '^'+' '.join([any_segment] * (i+1)) +'.*$'
-            if no_stress:
-                count = len(PhonoString.objects.filter(NoStress__regex = pattern))
-                totCount = len(PhonoString.objects.filter(NoStress__regex = totPattern))
-            else:
-                count = len(PhonoString.objects.filter(Transcription__regex = pattern))
-                totCount = len(PhonoString.objects.filter(Transcription__regex = totPattern))
+                                    =buckeyebrowser_wordtype.id)"""},
+                    where = ["ur REGEXP '%s'"],
+                    params = [pattern])
+            totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
+                    select = {
+                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                                FROM buckeyebrowser_underlying
+                                INNER JOIN buckeyebrowser_segmenttype
+                                ON buckeyebrowser_segmenttype.id
+                                    = buckeyebrowser_underlying.SegmentType_id
+                                WHERE buckeyebrowser_underlying.WordType_id
+                                    =buckeyebrowser_wordtype.id)"""},
+                    where = ["ur REGEXP '%s'"],
+                    params = [totPattern])
             SPprob += float(count) / float(totCount)
             if i != len(phones)-1:
                 patt = [any_segment] * i
                 patt.extend([phones[i],phones[i+1]])
                 pattern = '^'+' '.join(patt) +'.*$'
                 totPattern = '^'+' '.join([any_segment] * (i+2)) +'.*$'
-                if no_stress:
-                    count = len(PhonoString.objects.filter(NoStress__regex = pattern))
-                    totCount = len(PhonoString.objects.filter(NoStress__regex = totPattern))
-                else:
-                    count = len(PhonoString.objects.filter(Transcription__regex = pattern))
-                    totCount = len(PhonoString.objects.filter(Transcription__regex = totPattern))
+                count = WordType.objects.filter(Label__regex="^[^{<]").extra(
+                    select = {
+                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                                FROM buckeyebrowser_underlying
+                                INNER JOIN buckeyebrowser_segmenttype
+                                ON buckeyebrowser_segmenttype.id
+                                    = buckeyebrowser_underlying.SegmentType_id
+                                WHERE buckeyebrowser_underlying.WordType_id
+                                    =buckeyebrowser_wordtype.id)"""},
+                    where = ["ur REGEXP '%s'"],
+                    params = [pattern])
+                totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
+                    select = {
+                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                                FROM buckeyebrowser_underlying
+                                INNER JOIN buckeyebrowser_segmenttype
+                                ON buckeyebrowser_segmenttype.id
+                                    = buckeyebrowser_underlying.SegmentType_id
+                                WHERE buckeyebrowser_underlying.WordType_id
+                                    =buckeyebrowser_wordtype.id)"""},
+                    where = ["ur REGEXP '%s'"],
+                    params = [totPattern])
                 BPprob += float(count) / float(totCount)
         SPprob = SPprob / float(len(phones))
         BPprob = BPprob / float(len(phones)-1)
